@@ -44,9 +44,16 @@ class ExecutableWithSocketAgent(BaseIndependentAgent):
 
     def get_helper_process_request(self):
         if self.is_executable_configured():
-            return HelperProcessRequest(python_file_path=None, key=__file__ + str(self.get_port()),
-                                        executable=self.executable_path, exe_args=[str(self.get_port())],
-                                        current_working_directory=os.path.dirname(self.executable_path))
+            exe_args = [str(self.get_port())]
+            if (self.matchcomms_root is not None):
+                exe_args.extend(["--matchcomms-url", self.matchcomms_root.geturl()])
+
+            return HelperProcessRequest(
+                python_file_path=None,
+                key=__file__ + str(self.get_port()),
+                executable=self.executable_path,
+                exe_args=exe_args,
+                current_working_directory=os.path.dirname(self.executable_path))
         return None
 
     def retire(self):
