@@ -7,10 +7,10 @@ from typing import List
 from requirements.requirement import Requirement
 
 from rlbot.agents.base_agent import BaseAgent, BOT_CONFIG_MODULE_HEADER, BOT_NAME_KEY, LOOKS_CONFIG_KEY, \
-    PYTHON_FILE_KEY, LOGO_FILE_KEY, SUPPORTS_EARLY_START_KEY, LOADOUT_GENERATOR_FILE_KEY
+    PYTHON_FILE_KEY, LOGO_FILE_KEY, SUPPORTS_EARLY_START_KEY, LOADOUT_GENERATOR_FILE_KEY, SUPPORTS_STANDALONE
 from rlbot.agents.base_loadout_generator import BaseLoadoutGenerator
 from rlbot.agents.base_script import SCRIPT_FILE_KEY, BaseScript
-from rlbot.agents.rlbot_runnable import RLBotRunnable, REQUIREMENTS_FILE_KEY, REQUIRES_TKINTER
+from rlbot.agents.rlbot_runnable import RLBotRunnable, REQUIREMENTS_FILE_KEY, REQUIRES_TKINTER, USE_VIRTUAL_ENVIRONMENT_KEY
 from rlbot.utils.requirements_management import get_missing_packages, get_packages_needing_upgrade
 from rlbot.matchconfig.loadout_config import LoadoutConfig
 from rlbot.parsing.agent_config_parser import create_looks_configurations, PARTICIPANT_CONFIGURATION_HEADER, \
@@ -33,6 +33,7 @@ class RunnableConfigBundle:
         self.name = config_obj.get(BOT_CONFIG_MODULE_HEADER, BOT_NAME_KEY)
         self.supports_early_start = self.base_agent_config.get(BOT_CONFIG_MODULE_HEADER, SUPPORTS_EARLY_START_KEY)
         self.requirements_file = self.get_absolute_path(BOT_CONFIG_MODULE_HEADER, REQUIREMENTS_FILE_KEY)
+        self.use_virtual_environment = self.base_agent_config.getboolean(BOT_CONFIG_MODULE_HEADER, USE_VIRTUAL_ENVIRONMENT_KEY)
 
     def get_logo_file(self):
         # logo.png is a convention we established during the wintertide tournament.
@@ -57,10 +58,15 @@ class RunnableConfigBundle:
         special_reqs = []
         if self.base_agent_config.getboolean(BOT_CONFIG_MODULE_HEADER, REQUIRES_TKINTER):
             special_reqs.append('tkinter')
-        return get_missing_packages(requirements_file=self.requirements_file, special_reqs=special_reqs)
+
+        if self.use_virtual_environment:
+            # Ignore the requirements file for now, because we will be installing it automatically later!
+            return get_missing_packages(requirements_file=None, special_reqs=special_reqs)
+        else:
+            return get_missing_packages(requirements_file=self.requirements_file, special_reqs=special_reqs)
 
     def get_python_packages_needing_upgrade(self) -> List[Requirement]:
-        if self.requirements_file:
+        if self.requirements_file and not self.use_virtual_environment:
             return get_packages_needing_upgrade(requirements_file=self.requirements_file)
         return []
 
@@ -71,6 +77,7 @@ class BotConfigBundle(RunnableConfigBundle):
         self.base_agent_config = BaseAgent.base_create_agent_configurations()
         self.base_agent_config.parse_file(self.config_obj, config_directory=config_directory)
         self.python_file = self.get_absolute_path(BOT_CONFIG_MODULE_HEADER, PYTHON_FILE_KEY)
+        self.supports_standalone = self.base_agent_config.getboolean(BOT_CONFIG_MODULE_HEADER, SUPPORTS_STANDALONE)
         self.looks_path = self.get_absolute_path(BOT_CONFIG_MODULE_HEADER, LOOKS_CONFIG_KEY)
         self.loadout_generator_file = self.get_absolute_path(BOT_CONFIG_MODULE_HEADER, LOADOUT_GENERATOR_FILE_KEY)
 
