@@ -1,17 +1,12 @@
 import re
-from typing import Set, Tuple, Union
+import psutil
+from typing import Set, Tuple, Union, List, Dict
 import platform
 from rlbot.utils.logging_utils import get_logger, DEFAULT_LOGGER
-
-optional_packages_installed = False
-try:
-    import psutil
-    optional_packages_installed = True
-except ImportError:
-    pass
+from rlbot.botmanager.agent_metadata import AgentMetadata
 
 
-def configure_processes(agent_metadata_map, logger):
+def configure_processes(agent_metadata_map: Dict[int, AgentMetadata], logger):
     """
     This will update the priority and CPU affinity of the processes owned by bots to try to achieve fairness and
     good performance.
@@ -19,15 +14,6 @@ def configure_processes(agent_metadata_map, logger):
     :param agent_metadata_map: A mapping of player index to agent metadata, including a list of owned process ids.
     """
 
-    if not optional_packages_installed:
-        logger.warning("\n#### WARNING ####\n"
-                       "You are missing some optional packages which will become mandatory in the future!\n"
-                       "Please run `pip install -r requirements.txt` to enjoy optimal functionality "
-                       "and future-proof yourself!\n")
-
-    if not optional_packages_installed:
-        return
-
     team_pids_map = {}
 
     for player_index, data in agent_metadata_map.items():
@@ -37,10 +23,8 @@ def configure_processes(agent_metadata_map, logger):
         team_pids_map[team].update(data.pids)
 
     shared_pids = set()
-    cpu_count = psutil.cpu_count()
-    cpus_per_team = cpu_count // 3
 
-    if len(team_pids_map) >= 2 and cpus_per_team > 0:
+    if len(team_pids_map) >= 2 and len(get_team_cpus(0)) > 0:
         # Sort into three sets of pids: team 0 exclusives, team 1 exclusives, and shared pids
         # All pids will be assigned high priority
         # Team exclusive pids will be bound to a subset of cpus so they can't adversely affect the opposite team.
@@ -55,14 +39,11 @@ def configure_processes(agent_metadata_map, logger):
             team_set -= shared_pids
 
         for team, team_pids in team_pids_map.items():
-            team_cpu_offset = cpus_per_team * team
-            team_cpus = list(range(cpu_count - cpus_per_team - team_cpu_offset, cpu_count - team_cpu_offset))
+            team_cpus = get_team_cpus(team)
             for pid in team_pids:
                 try:
                     p = psutil.Process(pid)
-                    p.cpu_affinity(team_cpus)  # Restrict the process to run on the cpus assigned to the team
-                    if platform.system() == 'Windows': # TODO only works on windows
-                        p.nice(psutil.HIGH_PRIORITY_CLASS)  # Allow the process to run at high priority
+                    configure_process(p, team_cpus)
                 except Exception as e:
                     get_logger(DEFAULT_LOGGER).info(e)
     else:
@@ -73,12 +54,36 @@ def configure_processes(agent_metadata_map, logger):
     for pid in shared_pids:
         try:
             p = psutil.Process(pid)  # Allow the process to run at high priority
-            if platform.system() == 'Windows': # TODO only works on windows
+            if platform.system() == 'Windows':
                 p.nice(psutil.HIGH_PRIORITY_CLASS)
         except Exception as e:
             get_logger(DEFAULT_LOGGER).info(e)
 
 
+def configure_process(proc: psutil.Process, cores: List[int], infer_multi_team=False):
+    try:
+        if infer_multi_team:
+            existing_affinity = proc.cpu_affinity()
+            if len(existing_affinity) < psutil.cpu_count():
+                # The process in question has already been pinned to a subset of the CPUs.
+                # This might be a process spanning multiple teams, so we will set affinity to
+                # the combination of existing and newly requested cores.
+                cores = sorted(set(existing_affinity + cores))
+        proc.cpu_affinity(cores)
+
+        if platform.system() == 'Windows':
+            proc.nice(psutil.HIGH_PRIORITY_CLASS)  # Allow the process to run at high priority
+    except Exception as e:
+        get_logger(DEFAULT_LOGGER).info(e)
+
+
+def get_team_cpus(team: int) -> List[int]:
+    cpu_count = psutil.cpu_count()
+    cpus_per_team = cpu_count // 3
+    team_cpu_offset = cpus_per_team * team
+    return list(range(cpu_count - cpus_per_team - team_cpu_offset, cpu_count - team_cpu_offset))
+
+
 def extract_all_pids(agent_metadata_map):
     pids = set()
     for player_index, data in agent_metadata_map.items():
@@ -87,8 +92,6 @@ def extract_all_pids(agent_metadata_map):
 
 
 def is_process_running(program, scriptname, required_args: Set[str]) -> Tuple[bool, Union[psutil.Process, None]]:
-    if not optional_packages_installed:
-        return True, None
     # Find processes which contain the program or script name.
     matching_processes = []
     for process in psutil.process_iter():
