@@ -4,9 +4,19 @@
 # 3) we can import it into your module module
 # https://stackoverflow.com/questions/458550/standard-way-to-embed-version-into-python-package
 
-__version__ = '1.58.2'
+__version__ = '1.61.1'
 
 release_notes = {
+    '1.61.1': """
+    Getting flatbuffers from pypi instead of bundling the source directly. - tarehart + CodeRed
+    """,
+    '1.60.0': """
+    Adding Deadeye Canyon map. - Darxeal
+    """,
+    '1.59.2': """
+    People who use rlbot.cfg can now specify launcher_preference = steam or launcher_preference = epic.
+    See https://github.com/RLBot/RLBot/wiki/Config-File-Documentation#rlbot-configuration
+    """,
     '1.58.2': """
     Bots with python virtual environments will start up much faster. - VirxEC
     Bots can now have descriptive tags for better organization in RLBotGUI. - Darxeal
